<h1 align="center" style="font-size: 3rem">
  wheke-auth
</h1>

<p align="center">
  <em>A Pod that adds auth to Wheke</em>
</p>

<p align="center">
  <a href="https://github.com/humrochagf/wheke-auth/actions">
    <img src="https://github.com/humrochagf/wheke-auth/workflows/Test%20Suite/badge.svg" alt="Test Suite">
  </a>
  <a href="https://pypi.org/project/wheke-auth">
    <img src="https://img.shields.io/pypi/v/wheke-auth.svg" alt="PyPI - Version">
  </a>
  <a href="https://pypi.org/project/wheke-auth">
    <img src="https://img.shields.io/pypi/pyversions/wheke-auth.svg" alt="PyPI - Python Version">
  </a>
</p>

---

## Installation

```console
pip install wheke-auth
```
